@@ -1,7 +1,10 @@
 from django import template
+from urllib import quote_plus
+
+
 from threebot import __version__
-from ..utils import get_my_orgs, get_preset_worker, has_admin_permission
-from ..models import WorkflowPreset
+from threebot.utils import get_my_orgs, get_preset_worker, has_admin_permission
+from threebot.models import WorkflowPreset
 
 register = template.Library()
 
@@ -46,3 +49,18 @@ def get_presets_for(request, workflow):
 @register.assignment_tag
 def get_threebot_version():
     return __version__
+
+
+@register.filter
+def quoteplus(value):
+    return quote_plus(value)
+
+
+@register.filter
+def lsplit(s, splitter):
+    return s.split(splitter)[0]
+
+
+@register.filter
+def rsplit(s, splitter):
+    return s.split(splitter)[-1]
